@@ -82,8 +82,12 @@ class Initialize extends \Flake\Core\Controller {
 
                 # Default: PDO::SQLite or PDO::MySQL ?
                 $aPDODrivers = \PDO::getAvailableDrivers();
-                if (!in_array('sqlite', $aPDODrivers)) {    # PDO::MySQL is already asserted in \Baikal\Core\Tools::assertEnvironmentIsOk()
-                    $oDatabaseConfig->set("mysql", true);
+                if (in_array('sqlite', $aPDODrivers)) {    # PDO::MySQL is already asserted in \Baikal\Core\Tools::assertEnvironmentIsOk()
+                    $oDatabaseConfig->set("backend", 'sqlite');
+                } elseif (in_array('mysql', $aPDODrivers)) {
+                    $oDatabaseConfig->set("backend", 'mysql');
+                } else {
+                    $oDatabaseConfig->set("backend", 'pgsql');
                 }
 
                 $oDatabaseConfig->persist();
@@ -108,7 +112,7 @@ class Initialize extends \Flake\Core\Controller {
             exit(0);
 
         #$sMessage = "<p>Baïkal is now configured. You may <a class='btn btn-success' href='" . PROJECT_URI . "admin/'>Access the Baïkal admin</a></p>";
-            #$sForm = "";
+        #$sForm = "";
         } else {
             $sMessage = "";
             $sForm = $this->oForm->render();
