@@ -387,7 +387,7 @@ CREATE TABLE calendarinstances (
     UNIQUE (calendarid, share_href)
 );
 SQL
-        );
+                );
                 $this->aSuccess[] = 'Created calendarinstances table';
                 $pdo->exec('
 INSERT INTO calendarinstances
@@ -426,7 +426,7 @@ CREATE TABLE calendars (
     components text NOT NULL
 );
 SQL
-        );
+                );
                 $this->aSuccess[] = 'Created new calendars table';
             } else { // mysql
                 $pdo->exec(<<<SQL
@@ -450,7 +450,7 @@ CREATE TABLE calendarinstances (
     UNIQUE(calendarid, share_href)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;
 SQL
-        );
+                );
                 $this->aSuccess[] = 'Created calendarinstances table';
                 $pdo->exec('
 INSERT INTO calendarinstances
@@ -489,14 +489,14 @@ CREATE TABLE calendars (
     components VARBINARY(21)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
 SQL
-);
+                );
                 $this->aSuccess[] = 'Created new calendars table';
             }
 
             $pdo->exec(<<<SQL
 INSERT INTO calendars (id, synctoken, components) SELECT id, COALESCE(synctoken,1) as synctoken, COALESCE(components,"VEVENT,VTODO,VJOURNAL") as components FROM $calendarBackup
 SQL
-    );
+            );
             $this->aSuccess[] = 'Migrated calendars table';
         }
         if (version_compare($sVersionFrom, '0.9.4', '<')) {
@@ -505,6 +505,14 @@ SQL
             $this->aSuccess[] = 'Updated default values in calendarinstances table';
         }
 
+        if (version_compare($sVersionFrom, '0.10.0', '<')) {
+            $config = Yaml::parseFile(PROJECT_PATH_CONFIG . "baikal.yaml");
+
+            $oConfig = new \Baikal\Model\Config\Database();
+            $oConfig->set("backend", intval($config['database']['mysql']) === 1 ? 'mysql' : 'sqlite');
+            $oConfig->persist();
+        }
+
         $this->updateConfiguredVersion($sVersionTo);
 
         return true;
